django_auxilium.utils.functools.cache module
============================================

.. automodule:: django_auxilium.utils.functools.cache
    :members:
    :undoc-members:
    :show-inheritance:
